@@ -79,6 +79,9 @@ struct _ECalBackendGroupwisePrivate {
 
 	/* number of calendar items in the folder */
 	guint32 total_count;
+
+	/* timeout handler for syncing sendoptions */
+	guint sendoptions_sync_timeout;
 	
 	/* fields for storing info while offline */
 	char *user_email;
@@ -705,8 +708,14 @@ cache_init (ECalBackendGroupwise *cbgw)
 	}
 	cnc_status = e_gw_connection_get_settings (priv->cnc, &opts);	
 	if (cnc_status == E_GW_CONNECTION_STATUS_OK) {
-		e_cal_backend_groupwise_store_settings (opts, cbgw);
-		g_object_unref (opts);
+		GwSettings *hold = g_new0 (GwSettings, 1);
+
+		hold->cbgw = cbgw;
+		hold->opts = opts;
+		
+		/* We now sync the sendoptions into e-source using the GLIB main loop. Doing this operation
+		    in a thread causes crashes. */
+		priv->sendoptions_sync_timeout = g_idle_add ((GSourceFunc ) e_cal_backend_groupwise_store_settings, hold);
 	} else 
 		g_warning (G_STRLOC ": Could not get the settings from the server");
 	
@@ -1040,6 +1049,11 @@ e_cal_backend_groupwise_finalize (GObject *object)
 		priv->timeout_id = 0;
 	}
 
+	if (priv->sendoptions_sync_timeout) {
+		g_source_remove (priv->sendoptions_sync_timeout);
+		priv->sendoptions_sync_timeout = 0;
+	}
+
 	if (priv->default_zone) {
 		icaltimezone_free (priv->default_zone, 1);
 		priv->default_zone = NULL;
@@ -1780,8 +1794,8 @@ sanitize_component (ECalBackendSync *backend, ECalComponent *comp, char *server_
 		icalproperty_set_x_name (icalprop, "X-GWRECORDID");
 		icalcomponent_add_property (e_cal_component_get_icalcomponent (comp), icalprop);
 
-		g_string_free (str, TRUE);
 	}
+	g_string_free (str, TRUE);
 }
 
 static ECalBackendSyncStatus
@@ -2308,7 +2322,7 @@ change_status (ECalComponent *comp, icalparameter_partstat status, const char *e
 			prop = icalcomponent_get_next_property (icalcomp, ICAL_ATTENDEE_PROPERTY)) {
 		const char *attendee = icalproperty_get_attendee (prop);
 
-		if (!g_strncasecmp (attendee, "mailto:", 7))
+		if (!g_ascii_strncasecmp (attendee, "mailto:", 7))
 			attendee += 7;
 
 		if (!g_ascii_strcasecmp (attendee, email)) {
@@ -2681,6 +2695,7 @@ e_cal_backend_groupwise_init (ECalBackendGroupwise *cbgw, ECalBackendGroupwiseCl
 
 	priv->timeout_id = 0;
 	priv->cnc = NULL;
+	priv->sendoptions_sync_timeout = 0;
 
 	/* create the mutex for thread safety */
 	priv->mutex = g_mutex_new ();
